==> php82-nextcloud-29.0.7.tgz: share/nextcloud/apps/twofactor_backupcodes/l10n/sc.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "As creadu còdighes de còpia de seguresa a duos fatores pro su contu tuo",
    "Second-factor backup codes" : "Còdighes de còpia de seguresa a segundu fatore",
    "Generate backup codes" : "Gènera còdighes de còpia de seguresa",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "As ativadu s'autenticatzione a duos fatores ma no as ancora generadu is còdighes. Sunt netzessàrios pro ripristinare s'atzessu a su contu tuo s'in casu perdes su segundu fatore. ",
    "Backup code" : "Còdighe de còpia de seguresa",
    "Use backup code" : "Imprea còdighe de còpia de seguresa",
    "Two factor backup codes" : "Còdighes còpia de seguresa a duos fatores",
    "A two-factor auth backup codes provider" : "Unu frunidore de autenticatzione de còdighes de còpia de seguresa a duos fatores",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Is còdighes de còpia de seguresa si sunt generados. {used} de {total} còdighes sunt istados impreados.",
    "Save backup codes" : "Sarva còdighes de còpia de seguresa",
    "Print backup codes" : "Imprenta còdighes de còpia de seguresa",
    "Regenerate backup codes" : "Torra a generare còdighes de còpia de seguresa",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si torras a generare is còdighes de còpia de seguresa, in automàticu is còdighes betzos non sunt prus vàlidos.",
    "An error occurred while generating your backup codes" : "Ddoe at àpidu un'errore in sa creatzione de is còdighes de còpia de seguresa",
    "{name} backup codes" : "{name} còdighes de còpia de seguresa",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Imprea unu de is còdighes de còpia de seguresa chi as sarvadu candu impostas s'autenticatzione a duos fatores.",
    "Submit" : "Imbia",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Custos sunt is còdighes de còpia de seguresa tuos. Sarva·ddos e/o imprenta·ddos ca non ddos as a pòdere bìdere àteras bortas"
},
"nplurals=2; plural=(n != 1);");

==> php82-nextcloud-30.0.15.tgz: share/nextcloud/apps/twofactor_backupcodes/l10n/sc.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "As creadu còdighes de còpia de seguresa a duos fatores pro su contu tuo",
    "Second-factor backup codes" : "Còdighes de còpia de seguresa a segundu fatore",
    "Generate backup codes" : "Gènera còdighes de còpia de seguresa",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "As ativadu s'autenticatzione a duos fatores ma no as ancora generadu is còdighes. Sunt netzessàrios pro ripristinare s'atzessu a su contu tuo s'in casu perdes su segundu fatore. ",
    "Backup code" : "Còdighe de còpia de seguresa",
    "Use backup code" : "Imprea còdighe de còpia de seguresa",
    "Two factor backup codes" : "Còdighes còpia de seguresa a duos fatores",
    "A two-factor auth backup codes provider" : "Unu frunidore de autenticatzione de còdighes de còpia de seguresa a duos fatores",
    "An error occurred while generating your backup codes" : "Ddoe at àpidu un'errore in sa creatzione de is còdighes de còpia de seguresa",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Is còdighes de còpia de seguresa si sunt generados. {used} de {total} còdighes sunt istados impreados.",
    "Save backup codes" : "Sarva còdighes de còpia de seguresa",
    "Print backup codes" : "Imprenta còdighes de còpia de seguresa",
    "Regenerate backup codes" : "Torra a generare còdighes de còpia de seguresa",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Si torras a generare is còdighes de còpia de seguresa, in automàticu is còdighes betzos non sunt prus vàlidos.",
    "{name} backup codes" : "{name} còdighes de còpia de seguresa",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Imprea unu de is còdighes de còpia de seguresa chi as sarvadu cando cunfiguras s'autenticatzione a duos fatores.",
    "Submit" : "Imbia"
},
"nplurals=2; plural=(n != 1);");
